@@ -4,7 +4,6 @@
 
 from __future__ import annotations
 
-import json
 import os
 import subprocess
 import sys
@@ -19,9 +18,9 @@ from uuid import uuid4
 import pytest
 
 from ..base.constants import REPODATA_FN
-from ..base.context import conda_tests_ctxt_mgmt_def_pol, context
+from ..base.context import context
 from ..common.io import captured as common_io_captured
-from ..common.io import env_var
+from ..common.serialize import json
 from ..core.prefix_data import PrefixData
 from ..core.subdir_data import SubdirData
 from ..gateways.disk.delete import rm_rf
@@ -294,12 +293,10 @@ def _get_index_r_base(
         channels.append(channel)
         sd = SubdirData(channel)
         subdir_datas.append(sd)
-        with env_var(
-            "CONDA_ADD_PIP_AS_PYTHON_DEPENDENCY",
-            str(add_pip).lower(),
-            stack_callback=conda_tests_ctxt_mgmt_def_pol,
-        ):
+
+        with context._override("add_pip_as_python_dependency", add_pip):
             sd._process_raw_repodata_str(json.dumps(repodata))
+
         sd._loaded = True
         SubdirData._cache_[(channel.url(with_credentials=True), REPODATA_FN)] = sd
         _patch_for_local_exports(channel_name, sd)
@@ -536,24 +533,18 @@ def _get_solver_base(
 
     subdirs = (context.subdir,) if merge_noarch else (context.subdir, "noarch")
 
-    with (
-        patch.object(History, "get_requested_specs_map", return_value=spec_map),
-        env_var(
-            "CONDA_ADD_PIP_AS_PYTHON_DEPENDENCY",
-            str(add_pip).lower(),
-            stack_callback=conda_tests_ctxt_mgmt_def_pol,
-        ),
-    ):
-        # We need CONDA_ADD_PIP_AS_PYTHON_DEPENDENCY=false here again (it's also in
-        # get_index_r_*) to cover solver logics that need to load from disk instead of
-        # hitting the SubdirData cache
-        yield context.plugin_manager.get_solver_backend()(
-            tmpdir,
-            channels,
-            subdirs,
-            specs_to_add=specs_to_add,
-            specs_to_remove=specs_to_remove,
-        )
+    with context._override("add_pip_as_python_dependency", add_pip):
+        with patch.object(History, "get_requested_specs_map", return_value=spec_map):
+            # We need CONDA_ADD_PIP_AS_PYTHON_DEPENDENCY=false here again (it's also in
+            # get_index_r_*) to cover solver logics that need to load from disk instead of
+            # hitting the SubdirData cache
+            yield context.plugin_manager.get_solver_backend()(
+                tmpdir,
+                channels,
+                subdirs,
+                specs_to_add=specs_to_add,
+                specs_to_remove=specs_to_remove,
+            )
 
 
 @contextmanager
